#ifdef GL_ES
#define LOWP lowp
precision mediump float;
#else
#define LOWP
#endif

varying LOWP vec4 v_color;
varying vec2 v_texCoords0;
varying vec2 v_texCoords1;
varying float v_type;

uniform sampler2D u_texture;
uniform sampler2D u_texture1;

uniform vec2 uv_regionoffset;
uniform vec2 uv_regionsize;
uniform float time;


vec2 disc_center = vec2(0.5, 0.5);


float oscillate(float vMin, float vMax, float t) {
    float halfRange = (vMax - vMin) / vMax * 0.5;
    return (sin(t) * halfRange + (1.0 - halfRange)) * vMax;
}

float makeDisc(vec2 p, float b, float r) {
	return smoothstep(r + b, r - b, sqrt(dot(p, p)));
}

float makeCircle(vec2 p, float b, float r) {
    float dist =  sqrt(dot(p, p));
    return  1.0 + smoothstep(r, r+b, dist) - smoothstep(r-b, r, dist);
}

vec2 rot(float r, float deg) {
	return vec2(r * cos(radians(deg)), r * sin(radians(deg)));
}


void main()
{
    vec4 tex0 = texture2D(u_texture, v_texCoords0);

    vec2 diskpos = v_texCoords1;
    diskpos -= disc_center;

    float x = (disc_center.x - v_texCoords1.x);
	float y = (disc_center.y - v_texCoords1.y);
    float r = -(x*x + y*y) * 1.5;
    float z = 1.0 + 0.5*sin((r + time*0.1)/0.023);
    z = pow(z, 4.0);

    vec4 outerdisk = mix(vec4(tex0.rgb,0), vec4(tex0.rgb,z), makeDisc(diskpos, 0.1, 0.4));
    vec4 innerdisk = mix(outerdisk, tex0, makeDisc(diskpos, 0.15, 0.35));

    float x1 = (disc_center.x - v_texCoords1.x);
    float y1 = (disc_center.y - v_texCoords1.y  - 0.9);
    float r1 = -(x1*x1 + y1*y1) * 0.2;
    float z1 = sin((r1 + time*0.3)/0.1);
    z1 = pow( clamp(z1, 0.0, 1.0), 11.0 ) * 0.6;

    gl_FragColor = tex0+vec4(z1,z1,z1,0);
}